@@ -3,26 +3,16 @@ Test extended fields on tiddlers via the HTTP API.
 """
 
 
-from wsgi_intercept import httplib2_intercept
-import wsgi_intercept
 import httplib2
 import simplejson
 import simplejson
 
 from tiddlyweb.serializer import Serializer
 
-from fixtures import reset_textstore, _teststore, muchdata
+from fixtures import reset_textstore, _teststore, muchdata, initialize_app
 
 def setup_module(module):
-    from tiddlyweb.web import serve
-    # we have to have a function that returns the callable,
-    # Selector just _is_ the callable
-    def app_fn():
-        return serve.load_app()
-    #wsgi_intercept.debuglevel = 1
-    httplib2_intercept.install()
-    wsgi_intercept.add_wsgi_intercept('our_test_domain', 8001, app_fn)
-
+    initialize_app()
     reset_textstore()
     module.store = _teststore()
     muchdata(module.store)
